/*###############################################################################
---------------------------------------------------------------------------------
---                   Copyright 2010 Advantech Emb'Core
---   							   Advantech Co., Ltd.
---         THIS IS AN UNPUBLISHED WORK CONTAINING CONFIDENTIAL AND PROPRIETARY
---            INFORMATION WHICH IS THE PROPERTY OF ADVANTECH AUTOMATION CORP.
---
---       ANY DISCLOSURE, USE, OR REPRODUCTION, WITHOUT WRITTEN AUTHORIZATION FROM
---                  ADVANTECH AUTOMATION CORP., IS STRICTLY PROHIBITED.
---------------------------------------------------------------------------------
#################################################################################
---------------------------------------------------------------------------------
---   File:				Susi.h
---   Description:	SUSI API declarations.
---	Change log:		Version 1.0.2010.1010 <2009-12-07>, John modify from old version SUSI.
--------------------------------------------------------------------------------*/


#ifndef _SUSI_H_
#define _SUSI_H_


/* 
To use iManager at Windows CE OS platform, please define this line:
	#define WINCE_VER 1
To use iManager at Linux/QNX/Vxworks OS platform, please define this line:
	#define WINCE_VER 0
*/
#define WINCE_VER 0


#if WINCE_VER
#include <windows.h>
#endif


#if WINCE_VER
#define SUSIDLLAPI __declspec(dllexport)
#define SUSITCHAR wchar_t
#else
#define SUSIDLLAPI
#define SUSITCHAR char
#endif

#define SUSIRET_VOID					SUSIDLLAPI void
#define SUSIRET_INT					SUSIDLLAPI int
#define SUSIRET_BOOL					SUSIDLLAPI int
#define SUSIRET_ULONG				SUSIDLLAPI unsigned long

#if WINCE_VER
#define SUSIRET_ULONGLONG			SUSIDLLAPI ULONG64
#else
#define SUSIRET_ULONGLONG			SUSIDLLAPI unsigned long long
#endif

#define SUSI_BOARD_MAX_LEN_ID_STRING				8
#define SUSI_BOARD_MAX_SIZE_ID_STRING				16
#define SUSI_BOARD_MAX_LEN_SERIAL_STRING			12
#define SUSI_BOARD_MAX_SIZE_SERIAL_STRING			16
#define SUSI_BOARD_MAX_LEN_PART_STRING				16
#define SUSI_BOARD_MAX_SIZE_PART_STRING			20
#define SUSI_BOARD_MAX_LEN_EAN_STRING				10
#define SUSI_BOARD_MAX_SIZE_EAN_STRING				20	


#pragma pack(1)

typedef struct {

	unsigned short wYear;
	unsigned short wMonth;
	unsigned short wDayOfWeek;
	unsigned short wDay;
	unsigned short wHour;
	unsigned short wMinute;
	unsigned short wSecond;
	unsigned short wMilliseconds;

} SUSITIME;

typedef struct {
	unsigned long dwPowerOnCounter;/*4*/
	unsigned long dwRunningTimeCounter;/*4*/
	unsigned char bByteProtect[8];/*8*/
} SUSIBOARDCONFIGA;

#pragma pack()

typedef struct {
	
	unsigned short wBiosRevision; 
	unsigned short wFirmwareRevision;
	
} SUSIBOARDINFO;


typedef void *HSUSI;


#define SUSI_BOARD_OPEN_FLAGS_DEFAULT			0
#define SUSI_BOARD_OPEN_FLAGS_PRIMARYONLY		1

#define SUSI_VGA_CONTRAST_MAX						100
#define SUSI_VGA_BACKLIGHT_MAX					100


#define SUSI_VGA_TYPE_UNKNOWN						0x00000000
#define SUSI_VGA_TYPE_CRT							0x00010000
#define SUSI_VGA_TYPE_LCD							0x00020000
#define SUSI_VGA_TYPE_LCD_DVO						0x00020001
#define SUSI_VGA_TYPE_LCD_LVDS					0x00020002
#define SUSI_VGA_TYPE_TV							0x00030000

typedef struct {

  unsigned long dwSize;
  unsigned long dwType;
  unsigned long dwFlags;
  unsigned long dwNativeWidth;
  unsigned long dwNativeHeight;
  unsigned long dwRequestedWidth;
  unsigned long dwRequestedHeight;
  unsigned long dwRequestedBpp;
  unsigned long dwMaxBacklight;
  unsigned long dwMaxContrast;

  } SUSIVGAINFO;



#define SUSI_STORAGE_AREA_UNKNOWN   0
#define SUSI_STORAGE_AREA_EEPROM    0x00010000
#define SUSI_STORAGE_AREA_FLASH     0x00020000
#define SUSI_STORAGE_AREA_CMOS      0x00030000
#define SUSI_STORAGE_AREA_RAM       0x00040000


#define SUSI_I2C_TYPE_UNKNOWN			0
#define SUSI_I2C_TYPE_PRIMARY			0x00010000
#define SUSI_I2C_TYPE_SMB				0x00020000
#define SUSI_I2C_TYPE_DDC				0x00030000
#define SUSI_I2C_TYPE_EXT1_I2C		0x00060000
#define SUSI_I2C_TYPE_EXT2_I2C		0x00070000


typedef void (SUSI_WDOG_CALLBACK_EVENT_INT) ();


#define SUSI_WDOG_MODE_REBOOT_PC		0 
#define SUSI_WDOG_MODE_RESTART_OS	1
#define SUSI_WDOG_MODE_SHUTDOWN_OS  1

#define SUSI_WDOG_MODE_STAGED			0x80

enum { SWDModeRebootPC=0, SWDModeRestartOS=1, SWDModeStaged=0x80 };


#define SUSI_WDOG_OPMODE_DISABLED      0 
#define SUSI_WDOG_OPMODE_ONETIME_TRIG  1
#define SUSI_WDOG_OPMODE_SINGLE_EVENT  2
#define SUSI_WDOG_OPMODE_EVENT_REPEAT  3

#define SUSI_WDOG_EVENT_INT				0
#define SUSI_WDOG_EVENT_SCI				1 /*SMI or SCI*/
#define SUSI_WDOG_EVENT_RST				2
#define SUSI_WDOG_EVENT_BTN				3
#define SUSI_WDOG_EVENT_NMI				4

#define SUSI_WDOG_EVENT_MAX_STAGES		3

typedef struct {

  unsigned long dwTimeout;
  unsigned long dwEvent;

  } SUSIWDSTAGE;

typedef struct {
	
  unsigned long dwSize;
  unsigned long dwTimeout;
  unsigned long dwDelay;
  unsigned long dwMode; /*SUSI_WDOG_MODE_REBOOT_PC, SUSI_WDOG_MODE_RESTART_OS, SUSI_WDOG_MODE_STAGED*/
  unsigned long dwOpMode;/*SUSI_WDOG_OPMODE_DISABLED,SUSI_WDOG_OPMODE_ONETIME_TRIG,SUSI_WDOG_OPMODE_SINGLE_EVENT,SUSI_WDOG_OPMODE_EVENT_REPEAT*/
  unsigned long dwStageCount;
  SUSIWDSTAGE stStages[SUSI_WDOG_EVENT_MAX_STAGES];

  } SUSIWDCONFIG;

#define SUSI_WDOG_TYPE_UNKNOWN  0
#define SUSI_WDOG_TYPE_BC       0x00020000
#define SUSI_WDOG_TYPE_CHIPSET  0x00030000

typedef struct {

  unsigned long dwSize;
  unsigned long dwFlags;
  unsigned long dwMinTimeout;
  unsigned long dwMaxTimeout;
  unsigned long dwMinDelay;
  unsigned long dwMaxDelay;
  unsigned long dwOpModes;
  unsigned long dwMaxStageCount;
  unsigned long dwEvents;
  unsigned long dwType;

  } SUSIWDINFO;


#define SUSI_FAN_PWM_MAX				100
#define SUSI_FAN_TEMP_MIN				0
#define SUSI_FAN_TEMP_MAX				125
#define SUSI_FAN_RPM_MAX				0xFFFF

/*set Fan control type: Offset-0x02-bit7,bit6*/
#define SUSI_FAN_MODE_OFF           0x00
#define SUSI_FAN_MODE_FULL          0x01
#define SUSI_FAN_MODE_MANUAL        0x02
#define SUSI_FAN_MODE_AUTO          0x03 /*Smart fan control*/

#define SUSI_FAN_MODE_AUTO_ZONE0    0x00
#define SUSI_FAN_MODE_AUTO_ZONE1    0x01
#define SUSI_FAN_MODE_AUTO_ZONE2    0x02
#define SUSI_FAN_MODE_AUTO_ZONE3    0x03

#define SUSI_FAN_OPMODE_PWM			0
#define SUSI_FAN_OPMODE_RPM			1

typedef struct {

  unsigned long dwZone;
  unsigned long dwOpMode;
  unsigned long dwLowStopTemp;
  unsigned long dwLowTemp;
  unsigned long dwHighTemp; 
  unsigned long dwLowPWM; /*Percentage*/
  unsigned long dwHighPWM;
  unsigned long dwLowRPM;
  unsigned long dwHighRPM;

} SUSIAUTOFANCONFIG;

typedef struct {

  unsigned long dwSize;
  unsigned long dwMode;
  unsigned long dwPWM; /*optional parameters for auto fan mode*/
  SUSIAUTOFANCONFIG safConfig;

} SUSIFANCONFIG;

/*Temperature in units of 1/1000th degrees celcius*/

typedef struct {

  unsigned long dwSize;
  unsigned long dwType;
  unsigned long dwFlags;
  unsigned long dwAlarm;
  unsigned long dwRes;
  unsigned long dwMin;
  unsigned long dwMax;
  unsigned long dwAlarmHi;
  unsigned long dwHystHi;
  unsigned long dwAlarmLo;
  unsigned long dwHystLo;

  } SUSITEMPERATUREINFO;

/*Fan speed values in RPM (revolutions per minute)*/

typedef struct {

  unsigned long dwSize;
  unsigned long dwType;
  unsigned long dwFlags;
  unsigned long dwAlarm;
  unsigned long dwSpeedNom;
  unsigned long dwMin;
  unsigned long dwMax;
  unsigned long dwAlarmHi;
  unsigned long dwHystHi;
  unsigned long dwAlarmLo;
  unsigned long dwHystLo;
  unsigned long dwOutMin;
  unsigned long dwOutMax;

  } SUSIFANINFO;

/*Voltage in units of 1/1000th volt*/

typedef struct {

  unsigned long dwSize;
  unsigned long dwType;
  unsigned long dwNom;
  unsigned long dwFlags;
  unsigned long dwAlarm;
  unsigned long dwRes;
  unsigned long dwMin;
  unsigned long dwMax;
  unsigned long dwAlarmHi;
  unsigned long dwHystHi;
  unsigned long dwAlarmLo;
  unsigned long dwHystLo;

  } SUSIVOLTAGEINFO;



#define SUSI_TEMP_CPU           0x00010000
#define SUSI_TEMP_BOX           0x00020000
#define SUSI_TEMP_ENV           0x00030000
#define SUSI_TEMP_BOARD         0x00040000
#define SUSI_TEMP_BACKPLANE     0x00050000
#define SUSI_TEMP_CHIPSETS      0x00060000
#define SUSI_TEMP_VIDEO         0x00070000
#define SUSI_TEMP_OTHER         0x00080000
#define SUSI_TEMP_TOPDIMM_ENV   0x00090000 /*Top DIMM module environment temperature*/
#define SUSI_TEMP_BOTDIMM_ENV   0x000A0000 /*Bottom DIMM module environment temperature*/

#define SUSI_FAN_CPU            0x00010000
#define SUSI_FAN_BOX            0x00020000
#define SUSI_FAN_ENV            0x00030000
#define SUSI_FAN_CHIPSET        0x00040000
#define SUSI_FAN_VIDEO          0x00050000
#define SUSI_FAN_OTHER          0x00060000

#define SUSI_VOLTAGE_CPU        0x00010000
#define SUSI_VOLTAGE_DC         0x00020000
#define SUSI_VOLTAGE_DC_STANDBY 0x00030000
#define SUSI_VOLTAGE_BAT_CMOS   0x00040000
#define SUSI_VOLTAGE_BAT_POWER  0x00050000
#define SUSI_VOLTAGE_AC         0x00060000
#define SUSI_VOLTAGE_OTHER      0x00070000
#define SUSI_VOLTAGE_5V_S0      0x00080000
#define SUSI_VOLTAGE_5V_S5      0x00090000
#define SUSI_VOLTAGE_33V_S0     0x000A0000
#define SUSI_VOLTAGE_33V_S5     0x000B0000
#define SUSI_VOLTAGE_VCOREA     0x000C0000
#define SUSI_VOLTAGE_VCOREB     0x000D0000
#define SUSI_VOLTAGE_12V_S0     0x000E0000



#define SUSI_SENSOR_ACTIVE					0x01
#define SUSI_SENSOR_ALARM					0x02
#define SUSI_SENSOR_BROKEN					0x04
#define SUSI_SENSOR_SHORTCIRCUIT			0x08


#define SUSI_CPU_PERF_THROTTLING			1
#define SUSI_CPU_PERF_FREQUENCY			2


#ifdef __cplusplus
extern "C" {
#endif

/*DLL*/ 
SUSIRET_BOOL	SusiDllInitialize(void); 
SUSIRET_BOOL	SusiDllUninitialize(void); 
SUSIRET_BOOL	SusiDllIsAvailable(void);
SUSIRET_BOOL	SusiDllInstall(int install);
SUSIRET_ULONG	SusiDllGetLastError(void); 
SUSIRET_ULONGLONG SusiDllGetVersion(void);
/*SUSIRET_ULONGLONG SusiDllCoreVersion(void);*/
SUSIRET_ULONGLONG SusiDllGetDrvVersion(void);  

/*Board*/
SUSIRET_BOOL	SusiBoardClose(HSUSI hSusi);
SUSIRET_ULONG	SusiBoardCount(unsigned long dwClass, unsigned long dwFlags);
SUSIRET_BOOL	SusiBoardOpen(unsigned long dwClass, unsigned long dwNum, unsigned long dwFlags, HSUSI *phSusi);
SUSIRET_BOOL	SusiBoardOpenByName(const SUSITCHAR *pszName, HSUSI *phSusi);
SUSIRET_BOOL	SusiBoardGetName(HSUSI hSusi, SUSITCHAR *pszName, unsigned long dwSize);
SUSIRET_BOOL	SusiBoardGetInfo(HSUSI hSusi, SUSIBOARDINFO *pBoardInfo);
SUSIRET_BOOL	SusiBoardGetBootCounter(HSUSI hSusi, unsigned long *pdwCount);
SUSIRET_BOOL	SusiBoardGetRunningTimeMeter(HSUSI hSusi, unsigned long *pdwCount);

/*VGA*/
SUSIRET_ULONG	SusiVgaCount(HSUSI hSusi);
SUSIRET_BOOL	SusiVgaGetBacklight(HSUSI hSusi, unsigned long dwUnit, unsigned long *pdwSetting);
SUSIRET_BOOL	SusiVgaSetBacklight(HSUSI hSusi, unsigned long dwUnit, unsigned long dwSetting);
SUSIRET_BOOL	SusiVgaGetInfo(HSUSI hSusi, unsigned long dwUnit, SUSIVGAINFO *pInfo);
SUSIRET_BOOL	SusiVgaSetFrequency(HSUSI hSusi, unsigned long dwUnit, unsigned long dwSetting);
SUSIRET_BOOL	SusiVgaSetPolarity(HSUSI hSusi, unsigned long dwUnit, unsigned long dwSetting);
SUSIRET_BOOL	SusiVgaGetBacklightLevel(HSUSI hSusi, unsigned long dwUnit, unsigned long *pdwSetting);
SUSIRET_BOOL	SusiVgaSetBacklightLevel(HSUSI hSusi, unsigned long dwUnit, unsigned long dwSetting);


/*Storage Area*/
SUSIRET_ULONG	SusiStorageAreaCount(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_ULONG	SusiStorageAreaType(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_ULONG	SusiStorageAreaSize(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_ULONG	SusiStorageAreaBlockSize(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_BOOL	SusiStorageAreaRead(HSUSI hSusi, 
											  unsigned long dwUnit, 
											  unsigned long dwOffset, 
											  unsigned char *pBytes, 
											  unsigned long dwLen);
SUSIRET_BOOL	SusiStorageAreaWrite(HSUSI hSusi, 
												unsigned long dwUnit, 
												unsigned long dwOffset, 
												unsigned char *pBytes, 
												unsigned long dwLen);
SUSIRET_BOOL	SusiStorageAreaErase(HSUSI hSusi, 
												unsigned long dwUnit, 
												unsigned long dwOffset, 
												unsigned long dwLen);
SUSIRET_BOOL	SusiStorageAreaEraseStatus(HSUSI hSusi, 
														unsigned long dwUnit, 
														unsigned long dwOffset, 
														unsigned long dwLen, 
														unsigned long *lpStatus);
SUSIRET_BOOL	SusiStorageAreaLock(HSUSI hSusi, 
											  unsigned long dwUnit, 
											  unsigned long dwFlags, 
											  unsigned char *pBytes, 
											  unsigned long dwLen);
SUSIRET_BOOL	SusiStorageAreaUnlock(HSUSI hSusi, 
												 unsigned long dwUnit, 
												 unsigned long dwFlags, 
												 unsigned char *pBytes, 
												 unsigned long dwLen);
SUSIRET_BOOL	SusiStorageAreaIsLocked(HSUSI hSusi, 
													unsigned long dwUnit, 
													unsigned long dwFlags);


/*SMBus*/
SUSIRET_INT		SusiSMBusScanDevice(HSUSI hSusi, unsigned char bAddr_7);
SUSIRET_BOOL	SusiSMBusReadQuick(HSUSI hSusi, unsigned char bAddr);
SUSIRET_BOOL	SusiSMBusWriteQuick(HSUSI hSusi, unsigned char bAddr);
SUSIRET_BOOL	SusiSMBusReceiveByte(HSUSI hSusi, unsigned char bAddr, unsigned char *pDataByte);
SUSIRET_BOOL	SusiSMBusSendByte(HSUSI hSusi, unsigned char bAddr, unsigned char bData);
SUSIRET_BOOL	SusiSMBusReadByte(HSUSI hSusi, unsigned char bAddr, unsigned char bReg, unsigned char *pDataByte);
SUSIRET_BOOL	SusiSMBusWriteByte(HSUSI hSusi, unsigned char bAddr, unsigned char bReg, unsigned char bData);
SUSIRET_BOOL	SusiSMBusReadWord(HSUSI hSusi, unsigned char bAddr, unsigned char bReg, unsigned short *pDataWord);
SUSIRET_BOOL	SusiSMBusWriteWord(HSUSI hSusi, unsigned char bAddr, unsigned char bReg, unsigned short wData);

/*I2C*/
SUSIRET_ULONG	SusiI2CCount(HSUSI hSusi);
SUSIRET_ULONG	SusiI2CType(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_BOOL	SusiI2CIsAvailable(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_BOOL	SusiI2CRead(HSUSI hSusi, 
									unsigned long dwUnit, 
									unsigned char bAddr, 
									unsigned char *pBytes, 
									unsigned long dwLen);
SUSIRET_BOOL	SusiI2CWrite(HSUSI hSusi, 
									 unsigned long dwUnit, 
									 unsigned char bAddr, 
									 unsigned char *pBytes, 
									 unsigned long dwLen);
SUSIRET_BOOL	SusiI2CReadRegister(HSUSI hSusi, 
											  unsigned long dwUnit, 
											  unsigned char bAddr, 
											  unsigned short wReg, 
											  unsigned char *pDataByte);
SUSIRET_BOOL	SusiI2CWriteRegister(HSUSI hSusi, 
												unsigned long dwUnit, 
												unsigned char bAddr, 
												unsigned short wReg, 
												unsigned char bData);
SUSIRET_BOOL	SusiI2CWriteReadCombined(HSUSI hSusi, 
													 unsigned long dwUnit, 
													 unsigned char bAddr, 
													 unsigned char *pBytesWrite, 
													 unsigned long dwLenWrite, 
													 unsigned char *pBytesRead, 
													 unsigned long dwLenRead);
SUSIRET_BOOL	SusiI2CGetMaxFrequency(HSUSI hSusi, unsigned long dwUnit, unsigned long *pdwSetting); 
SUSIRET_BOOL	SusiI2CGetFrequency(HSUSI hSusi, unsigned long dwUnit, unsigned long *pdwSetting); 
SUSIRET_BOOL	SusiI2CSetFrequency(HSUSI hSusi, unsigned long dwUnit, unsigned long dwSetting);

/*GPIO*/
SUSIRET_ULONG	SusiIOCount(HSUSI hSusi);
SUSIRET_BOOL	SusiIOIsAvailable(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_BOOL	SusiIORead(HSUSI hSusi, unsigned long dwUnit, unsigned long *pdwData);
SUSIRET_BOOL	SusiIOWrite(HSUSI hSusi, unsigned long dwUnit, unsigned long dwData);
SUSIRET_BOOL	SusiIOGetDirection(HSUSI hSusi, unsigned long dwUnit, unsigned long *pdwData);
SUSIRET_BOOL	SusiIOSetDirection(HSUSI hSusi, unsigned long dwUnit, unsigned long dwData);
SUSIRET_BOOL	SusiIOGetDirectionCaps(HSUSI hSusi, 
												  unsigned long dwUnit, 
												  unsigned long *pdwInputs, 
												  unsigned long *pdwOutputs);

/*WDT*/
SUSIRET_ULONG	SusiWDogCount(HSUSI hSusi);
SUSIRET_BOOL	SusiWDogIsAvailable(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_BOOL	SusiWDogTrigger(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_BOOL	SusiWDogGetConfigStruct(HSUSI hSusi, unsigned long dwUnit, SUSIWDCONFIG *pConfig);
SUSIRET_BOOL	SusiWDogSetConfigStruct(HSUSI hSusi, unsigned long dwUnit, SUSIWDCONFIG *pConfig);
SUSIRET_BOOL	SusiWDogSetConfig(HSUSI hSusi, 
											unsigned long dwUnit, 
											unsigned long timeout, 
											unsigned long delay, 
											unsigned long mode);
SUSIRET_BOOL	SusiWDogDisable(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_BOOL	SusiWDogGetInfo(HSUSI hSusi, unsigned long dwUnit, SUSIWDINFO *pInfo); /*Congatec*/
SUSIRET_BOOL	SusiWDogSetIntCallBack(HSUSI hSusi, 
												  unsigned long dwUnit, 
												  SUSI_WDOG_CALLBACK_EVENT_INT *fnCallBack); /*Advantech only*/

/*FAN*/
SUSIRET_ULONG	SusiFanCount(HSUSI hSusi);
SUSIRET_BOOL	SusiFanIsAvailable(HSUSI hSusi, unsigned long dwUnit);
SUSIRET_BOOL	SusiFanSetConfigStruct(HSUSI hSusi, unsigned long dwUnit, SUSIFANCONFIG *pConfig);
SUSIRET_BOOL	SusiFanGetConfigStruct(HSUSI hSusi, unsigned long dwUnit, SUSIFANCONFIG *pConfig);
SUSIRET_BOOL	SusiFanGetInfo(HSUSI hSusi, unsigned long dwUnit, SUSIFANINFO *pInfo);
SUSIRET_BOOL	SusiFanGetCurrent(HSUSI hSusi, 
											unsigned long dwUnit, 
											unsigned long *pdwSetting, 
											unsigned long *pdwStatus);
SUSIRET_BOOL	SusiFanSetLimits(HSUSI hSusi, unsigned long dwUnit, SUSIFANINFO *pInfo);

/*TEMP*/
SUSIRET_ULONG	SusiTemperatureCount(HSUSI hSusi);
SUSIRET_BOOL	SusiTemperatureGetInfo(HSUSI hSusi, unsigned long dwUnit, SUSITEMPERATUREINFO *pInfo);
SUSIRET_BOOL	SusiTemperatureGetCurrent(HSUSI hSusi, 
													  unsigned long dwUnit, 
													  unsigned long *pdwSetting, 
													  unsigned long *pdwStatus);
SUSIRET_BOOL	SusiTemperatureSetLimits(HSUSI hSusi, 
													 unsigned long dwUnit, 
													 SUSITEMPERATUREINFO *pInfo);

/*VOLT*/
SUSIRET_ULONG	SusiVoltageCount(HSUSI hSusi);
SUSIRET_BOOL	SusiVoltageGetInfo(HSUSI hSusi, unsigned long dwUnit, SUSIVOLTAGEINFO *pInfo);
SUSIRET_BOOL	SusiVoltageGetCurrent(HSUSI hSusi, 
												 unsigned long dwUnit, 
												 unsigned long *pdwSetting, 
												 unsigned long *pdwStatus);
SUSIRET_BOOL	SusiVoltageSetLimits(HSUSI hSusi, unsigned long dwUnit, SUSIVOLTAGEINFO *pInfo);


#ifdef __cplusplus
}
#endif



#endif /*#ifndef _SUSI_H_*/


