#include <stdio.h>
#include <stdlib.h>
#include "Susi.h"
#include "rel_debug.h"
#include "rel_errlib.h"
#include "rel_errdrv.h"

HSUSI hSusi;

int ECInit()
{
	if (!SusiDllInitialize())
	{
		printf("SusiDllInitialize() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInitialize() OK.\r\n");
	}
	
	if( !SusiDllInstall(1) )
	{
		SusiDllUninitialize();
		printf("SusiDllInstall(1) failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInstall(1) OK.\r\n");
	}
	
	if (!SusiBoardOpen(0,0,0, &hSusi))
	{
		SusiDllInstall(0);
		SusiDllUninitialize();
		printf("SusiBoardOpen() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiBoardOpen() OK.\r\n");
	}
	
	return 0;
}

void ECRelease()
{
	SusiBoardClose(hSusi);
	
	SusiDllInstall(0);
	
	SusiDllUninitialize();
}

int get_count()
{	
	printf("Fan Count: %ld\r\n", SusiFanCount(hSusi));
	
	return 0;
}

int get_info()
{
	SUSIFANINFO Info;
	int data;
	unsigned long unit;

	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	if( SusiFanGetInfo(hSusi, unit, &Info) )
	{
		printf("Info.dwType: 0x%lX\r\n",Info.dwType);
		printf("Info.dwSpeedNom: %ld\r\n",Info.dwSpeedNom);
		printf("Info.dwMax: %ld\r\n",Info.dwMax);
		printf("Info.dwMin: %ld\r\n",Info.dwMin);
		printf("Info.dwFlags: %ld\r\n",Info.dwFlags);
		printf("Info.dwAlarm: %ld\r\n",Info.dwAlarm);
		printf("Info.dwAlarmHi: %ld\r\n",Info.dwAlarmHi);
		printf("Info.dwAlarmLo: %ld\r\n",Info.dwAlarmLo);
		printf("Info.dwHystHi: %ld\r\n",Info.dwHystHi);
		printf("Info.dwOutMax: %ld\r\n",Info.dwOutMax);
		printf("Info.dwOutMin: %ld\r\n",Info.dwOutMin);
	}
	else
	{
		printf("Get info failed!!!\r\n");
	}

	return 0;
}

int get_current()
{
	int data;
	unsigned long unit;
	unsigned long value;
	unsigned long status;

	
	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;
	
	if( SusiFanGetCurrent(hSusi, unit, &value, &status) )
	{
		printf("Value: %ld\r\n",value);
		printf("Status: %ld\r\n",status);
	}
	else
	{
		printf("Get value failed!!!\r\n");
	}
	
	return 0;
}

int get_config()
{
	SUSIFANCONFIG Config;
	int data;
	unsigned long unit;
	
	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;
	
	if( SusiFanGetConfigStruct(hSusi, unit, &Config) )
	{
		printf("Config.dwMode: 0x%lX\r\n",Config.dwMode);
		printf("Config.dwPWM: %ld\r\n",Config.dwPWM);
		printf("Config.safConfig.dwOpMode: 0x%lX\r\n",Config.safConfig.dwOpMode);
		printf("Config.safConfig.dwLowStopTemp: %ld\r\n",Config.safConfig.dwLowStopTemp);
		printf("Config.safConfig.dwLowTemp: %ld\r\n",Config.safConfig.dwLowTemp);
		printf("Config.safConfig.dwHighTemp: %ld\r\n",Config.safConfig.dwHighTemp);
		printf("Config.safConfig.dwLowPWM: %ld\r\n",Config.safConfig.dwLowPWM);
		printf("Config.safConfig.dwHighPWM: %ld\r\n",Config.safConfig.dwHighPWM);
		printf("Config.safConfig.dwLowRPM: 0x%lx\r\n",Config.safConfig.dwLowRPM);
		printf("Config.safConfig.dwHighRPM: 0x%lx\r\n",Config.safConfig.dwHighRPM);
	}
	else
	{
		printf("Get configuration failed!!!\r\n");
	}
	
	return 0;
}

int set_config()
{
	SUSIFANCONFIG Config = {0};
	int data;
	unsigned long unit;
	
	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	printf("Please input configuration mode: (0: Off, 1: Full, 2: Manual, 3: Auto)\r\n");
	scanf("%i", &data);
	switch(data)
	{
	case 0:
		Config.dwMode = SUSI_FAN_MODE_OFF;
		goto SET_FAN_CONF;	
	case 1:
		Config.dwMode = SUSI_FAN_MODE_FULL;
		goto SET_FAN_CONF;	
	case 2:
		Config.dwMode = SUSI_FAN_MODE_MANUAL;
		printf("Please input PWM value: (range: 0 ~ 100)\r\n");
		scanf("%i", &data);
		Config.dwPWM = (unsigned int)data;
		goto SET_FAN_CONF;
	case 3:
	default:
		Config.dwMode = SUSI_FAN_MODE_AUTO;
		break;
	}

	/*Auto Mode*/
	printf("Please input operation mode: (0: PWM, 1: RPM)\r\n");
	scanf("%i", &data);
	switch(data)
	{
	case 1:
		Config.safConfig.dwOpMode = SUSI_FAN_OPMODE_RPM;
		printf("Please input low RPM value: (0 ~ 0xFFFF, Hex)\r\n");	
		scanf("%x", &data);
		Config.safConfig.dwLowRPM= (unsigned int)data;
		printf("Please input high RPM value: (Low ~ 0xFFFF, Hex)\r\n");	
		scanf("%x", &data);
		Config.safConfig.dwHighRPM = (unsigned int)data;
		break;	
	case 0:
	default:
		Config.safConfig.dwOpMode = SUSI_FAN_OPMODE_PWM;
		printf("Please input low PWM value: (0 ~ 100)\r\n");
		scanf("%i", &data);
		Config.safConfig.dwLowPWM = (unsigned int)data;
		printf("Please input high PWM value: (Low ~ 100)\r\n");
		scanf("%i", &data);
		Config.safConfig.dwHighPWM = (unsigned int)data;
		break;
	}

	printf("Please input stop temperature value: (0 ~ 125)\r\n");
	scanf("%i", &data);
	Config.safConfig.dwLowStopTemp = (unsigned int)data;

	printf("Please input low temperature value: (stop ~ 125)\r\n");
	scanf("%i", &data);
	Config.safConfig.dwLowTemp = (unsigned int)data;

	printf("Please input high temperature value: (low ~ 125)\r\n");
	scanf("%i", &data);
	Config.safConfig.dwHighTemp = (unsigned int)data;	
	

SET_FAN_CONF:
	
	if( SusiFanSetConfigStruct(hSusi, unit, &Config) )
	{	
		printf("Set configuration OK.\r\n");
	}
	else
	{
		printf("Set configuration failed!!!\r\n");
	}
	
	return 0;
}


void show_menu(void)
{
	printf("\r\n");
	printf("0) Terminate this program\r\n");
	printf("1) Get fan count\r\n");
	printf("2) Get target fan info\r\n");	
	printf("3) Get target fan current value\r\n");	
	printf("4) Get target fan configuration\r\n");
	printf("5) Set target fan configuration\r\n");
	printf("Enter your choice: \r\n");
}

int main( int argc, char *argv[] )
{
	int result, done, op;
	
	printf("***********************Fan test enter.***********************\r\n");
	
	if ( 0 != ECInit() )
	{
		printf("EC Init failed.\r\n");
		return -1;
	}
	else
	{
		printf("EC Init OK.\r\n");
	}

	done = 0;
	result = 0;
	
	while (!done)
	{
		show_menu();
		
		scanf("%i", &op);
		
		switch (op)
		{
		case 0:
			done = 1;
			continue;
		case 1:
			result = get_count();
			break;
		case 2:
			result = get_info();
			break;
		case 3:
			result = get_current();
			break;		
		case 4:
			result = get_config();
			break;
		case 5:
			result = set_config();
			break;
		default:
			printf("\r\nUnknown choice!\r\n");	
		} /*switch (op)*/
		
		if(done != 1 && result < 0) 
		{
			ECRelease();
			
			printf("***********************Fan test exit.***********************\r\n");
			return 0;
		}
		
	} /*while (!done)*/
	
	ECRelease();

	printf("***********************Fan test exit.***********************\r\n");

	return 0;
}

