#include <stdio.h>
#include <stdlib.h>
#include "Susi.h"
#include "rel_debug.h"
#include "rel_errlib.h"
#include "rel_errdrv.h"

#define GPIO_UNIT_NUM 8

HSUSI hSusi;
unsigned long ulGPIOCount;

int ECInit()
{
	if (!SusiDllInitialize())
	{
		printf("SusiDllInitialize() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInitialize() OK.\r\n");
	}
	
	if( !SusiDllInstall(1) )
	{
		SusiDllUninitialize();
		printf("SusiDllInstall(1) failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInstall(1) OK.\r\n");
	}
	
	if (!SusiBoardOpen(0,0,0, &hSusi))
	{
		SusiDllInstall(0);
		SusiDllUninitialize();
		printf("SusiBoardOpen() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiBoardOpen() OK.\r\n");
	}
	
	return 0;
}

void ECRelease()
{
	SusiBoardClose(hSusi);
	
	SusiDllInstall(0);
	
	SusiDllUninitialize();
}

void CheckAvailableGPIO()
{
	int i;
	
	for( i = 0; i < GPIO_UNIT_NUM; i ++ )
	{
		if( SusiIOIsAvailable( hSusi, i ) )
		{
			printf( " GPIO Unit %d exist.\r\n", i );
		}
		else
		{
			printf( " GPIO Unit %d is not available.\r\n", i );
		}
	}	
}

void ShowGPIOBaseInfo()
{	
	int i;
	unsigned long ulInputs; 
	unsigned long ulOutputs;
	unsigned long ulDirection;

	ulGPIOCount = SusiIOCount(hSusi);

	printf("CPIO base information:\r\n");
	printf("GPIO total unit count is: %ld\r\n", ulGPIOCount);	

	for( i = 0; i < ulGPIOCount; i ++ )
	{
		if( SusiIOGetDirectionCaps( hSusi, i, &ulInputs, &ulOutputs ) )
		{			
			printf( "GPIO Unit %d DirectionCaps: Could be set as %s %s\r\n", 
				i, 
				(ulInputs ? "Input" : ""), 
				(ulOutputs ? "Output" : "") );
		} 
		if( SusiIOGetDirection( hSusi, i, &ulDirection ) )
		{			
			printf( "GPIO Unit %d now direction is: %s\r\n", 
				i, 
				(ulDirection ? "Input" : "Output") );
		}
	}
	
}

void show_menu(void)
{
	printf("\r\n");
	printf("0) Terminate this program\r\n");
	printf("1) Get GPIO pin direction mask\r\n");	
	printf("2) Read GPIO pin\r\n");
	printf("3) Write GPIO pin\r\n");	
	printf("4) Set GPIO pin direction\r\n");
	printf("Enter your choice: \r\n");
}

int get_dir_mask()
{
	char ch[GPIO_UNIT_NUM +1] = {0};
	int i;
	unsigned long ulDirection;


	for(i = 0; i < ulGPIOCount; i ++)
	{
		if( SusiIOGetDirection( hSusi, i, &ulDirection ) )
		{			
			ulDirection ? (ch[ulGPIOCount - 1 - i] = '1') : (ch[ulGPIOCount - 1 - i] = '0');
		}
		else
		{
			ch[ulGPIOCount - 1 - i] = 'x';
		}
	}

	printf("GPIO pins direction mask (\'1\': Input, \'0\': Onput, \'x\': Get Failed.) :\r\n   ");
	printf("%s\r\n", ch);

	return 0;
}

int read_pins()
{
	char ch[GPIO_UNIT_NUM +1] = {0};
	int i;
	unsigned long ulData;

	
	for(i = 0; i < ulGPIOCount; i ++)
	{
		if( SusiIORead( hSusi, i, &ulData ) )
		{			
			ulData ? (ch[ulGPIOCount - 1 - i] = '1') : (ch[ulGPIOCount - 1 - i] = '0');
		}
		else
		{
			ch[ulGPIOCount - 1 - i] = 'x';
		}
	}
	
	printf("GPIO pins signal mask (\'1\': High, \'0\': Low, \'x\': Read Failed.) :\r\n   ");
	printf("%s\r\n", ch);
	
	return 0;
}

int write_pin()
{
	int data;
	unsigned long unit;
	unsigned long status;
	unsigned long ulDirection;
	
	printf("Which GPIO Unit:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	if( SusiIOGetDirection( hSusi, unit, &ulDirection ) )
	{			
		if(ulDirection)
		{
			printf("GPIO Unit %ld is Input pin and could not be writed. Operation failed.\r\n", unit);		
			return 0;
		}
	}
	
	printf("Value (0 or 1):\r\n");
	scanf("%i",&data);
	status = (unsigned long) data;
	
	if( SusiIOWrite( hSusi, unit, status ) )
	{			
		printf("Write GPIO Unit %ld as %s successful.\r\n", unit, ( status ? ("High") : ("Low") ) );
	}
	else
	{
		printf("Write GPIO Unit %ld as %s failed!!!\r\n", unit, ( status ? ("High") : ("Low") ) );
	}

	return 0;
}

int set_dir()
{
	int data;
	unsigned long unit;
	unsigned long status;

	printf("Which GPIO Unit:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	printf("direction (input pin :1, output pin:0 ):\r\n");
	scanf("%i",&data);
	status = (unsigned long) data;

	if( SusiIOSetDirection( hSusi, unit, status ) )
	{			
		printf("Set GPIO Unit %ld as %s successful.\r\n", unit, ( status ? ("Input") : ("Output") ) );
	}
	else
	{
		printf("Set GPIO Unit %ld as %s failed!!!\r\n", unit, ( status ? ("Input") : ("Output") ) );
	}

	return 0;
}

int main( int argc, char *argv[] )
{
	int result, done, op;
	
	printf("***********************GPIO test enter.***********************\r\n");
	
	if ( 0 != ECInit() )
	{
		printf("EC Init failed.\r\n");
		return -1;
	}
	else
	{
		printf("EC Init OK.\r\n");
	}

	CheckAvailableGPIO();

	ShowGPIOBaseInfo();	

	done = 0;
	result = 0;

	while (!done)
	{
		show_menu();
		
		scanf("%i", &op);

		switch (op)
		{
		case 0:
			done = 1;
			continue;
		case 1:
			result = get_dir_mask();
			break;
		case 2:
			result = read_pins();
			break;
		case 3:
			result = write_pin();
			break;
		case 4:
			result = set_dir();
			break;
		default:
			printf("\r\nUnknown choice!\r\n");	
		} /*switch (op)*/

		if(done != 1 && result < 0) 
		{
			ECRelease();

			printf("***********************GPIO test exit.***********************\r\n");
			return 0;
		}

	} /*while (!done)*/

	
	ECRelease();

	printf("***********************GPIO test exit.***********************\r\n");

	return 0;
}

