#include <stdio.h>
#include <stdlib.h>
#include "Susi.h"
#include "rel_debug.h"
#include "rel_errlib.h"
#include "rel_errdrv.h"

HSUSI hSusi;

int ECInit()
{
	if (!SusiDllInitialize())
	{
		printf("SusiDllInitialize() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInitialize() OK.\r\n");
	}
	
	if( !SusiDllInstall(1) )
	{
		SusiDllUninitialize();
		printf("SusiDllInstall(1) failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInstall(1) OK.\r\n");
	}
	
	if (!SusiBoardOpen(0,0,0, &hSusi))
	{
		SusiDllInstall(0);
		SusiDllUninitialize();
		printf("SusiBoardOpen() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiBoardOpen() OK.\r\n");
	}
	
	return 0;
}

void ECRelease()
{
	SusiBoardClose(hSusi);
	
	SusiDllInstall(0);
	
	SusiDllUninitialize();
}


void show_menu(void)
{
	printf("\n");
	printf("0) Terminate this program\n");
	printf("1) Read for i2c\n");
	printf("2) Write to i2c\n");
	printf("3) Read Register for i2c\n");
	printf("4) Write Register to i2c\n");
	printf("5) Write Read Combine\n");
	printf("Enter your choice: \n");
}

int read_byte(void)
{
	int data, i, Len = -1;
	unsigned char address;
	unsigned char *storage;

	printf("Please input 8-bit address of the slave device (Hex):\n");
	scanf("%x", &data);
	address = (unsigned char) data;

	printf("Please input data length to be read:\n");
	scanf("%i", &data);
	Len = data;

	if( ( Len > 0 ) && ((storage = malloc(Len)) != 0) )
	{		
		if ( !SusiI2CRead(hSusi, 0, address, storage, Len) ) 
		{
			free(storage);
			printf("SusiI2CRead() failed.\n");
			return 0;
		}
		else
		{
			printf("Data read (Hex):\n");
			for ( i = 0; i < Len; i++)
			{				
				printf("%02x ", storage[i]);
			}
			printf("\n");
			printf("Read successful.\n");
		}
		
		free(storage);
		return 1;
	}

	return 0;
}


int write_byte(void)
{
	int data, i, Len = -1;
	unsigned char address;
	unsigned char *storage;

	printf("Please input 8-bit address of the slave device (Hex):\n");
	scanf("%x", &data);
	address = (unsigned char) data;

	printf("Please input data length to be writed:\n");
	scanf("%i", &data);
	Len =  data;

	if ( (Len > 0) && ((storage = malloc(Len)) != 0) )
	{
		for ( i = 0; i < Len; i++)
		{
        	printf("Please input NO. %d data value (Hex):\n", i);
        	scanf("%x", &data);
        	storage[i] = (unsigned char) data;
		}		
	 
		if (!SusiI2CWrite(hSusi, 0, address, storage, Len)) 
		{
			free(storage);
			printf("SusiI2CWrite() failed.\n");
			return 0;
		}

		printf("Write successful.\n");
		return 1;
	}

	return 0;
}

int read_register(void)
{
	int data;
	unsigned char address;
	unsigned short reg;
	unsigned char storage;
	
	printf("Please input 8-bit address of the slave device (Hex):\n");
	scanf("%x", &data);
	address = (unsigned char) data;
	
	printf("Please input the register address (Hex):\n");
	scanf("%x", &data);
	reg = (unsigned short) data;
	
	if ( !SusiI2CReadRegister(hSusi, 0, address, reg, &storage) ) 
	{	
		printf("SusiI2CReadRegister() failed.\n");
		return 0;
	}
	else
	{
		printf("Data read (Hex):\n");
		printf("%02x\n", storage);	
		printf("Read successful.\n");
		return 1;
	}
	
	return 0;
}

int write_register(void)
{
	int data;
	unsigned char address;
	unsigned short reg;
	unsigned char storage;
	
	printf("Please input 8-bit address of the slave device (Hex):\n");
	scanf("%x", &data);
	address = (unsigned char) data;
	
	printf("Please input the register address (Hex):\n");
	scanf("%x", &data);
	reg = (unsigned short) data;

	printf( "Please input data value to be writed (Hex):\n" );
	scanf("%x", &data);
	storage = (unsigned char) data;
	
	if ( !SusiI2CWriteRegister(hSusi, 0, address, reg, storage) ) 
	{	
		printf("SusiI2CWriteRegister() failed.\n");
		return 0;
	}
	else
	{
		printf("Write successful.\n");
		return 1;
	}
	
	return 0;
}

int write_read_combine(void)
{
	int data, i, writeLen = -1, readLen = -1;
	unsigned char address;
	unsigned char *wstorage, *rstorage;

	printf("Please input 8-bit address of the slave device (Hex):\n");
	scanf("%x", &data);
	address = (unsigned char) data;

	printf("Please input data length to be writed:\n");
	scanf("%i", &data);
	writeLen = data;
    
	printf("Please input data length to be read:\n");
	scanf("%i", &data);
	readLen = data;

	if ( (writeLen > 0) && ((wstorage = malloc(writeLen)) != 0) &&
		(readLen > 0) && ((rstorage = malloc(readLen)) != 0))
	{
		for ( i = 0; i < writeLen; i++)
		{
        	printf("Please input NO. %d data value (Hex):\n", i);
        	scanf("%x", &data);
        	wstorage[i] = (unsigned char) data;
		}		
	
		if ( !SusiI2CWriteReadCombined(hSusi, 0, address, wstorage, writeLen, rstorage, readLen) ) 
		{
			free(wstorage);
			free(rstorage);
			printf("SusiI2CWriteReadCombined() failed.\n");
			return 0;
		}
		else
		{
			printf("Data read (Hex):\n");
			for ( i = 0; i < readLen; i++)
			{				
				printf("%02x ", rstorage[i]);
			}
			printf("\n");
			printf("Read successful.\n");
		}
		
		free(wstorage);
		free(rstorage);
		
		return 1;		
	}
	
	return 0;
}

int main(void)
{
	int result, done, op;
	
	printf("***********************IIC test enter.***********************\r\n");
	
	if ( 0 != ECInit() )
	{
		printf("EC Init failed.\r\n");
		return -1;
	}
	else
	{
		printf("EC Init OK.\r\n");
	}
	
	done = 0;
	result = 0;

	while (! done) 
	{
		show_menu();

		scanf("%i", &op);

		switch (op)
		{
		case 0:
			done = 1;
			continue;
		case 1:
			result = read_byte();
			break;
		case 2:
			result = write_byte();
			break;
		case 3:
			result = read_register();
			break;
		case 4:
			result = write_register();
			break;
		case 5:
			result = write_read_combine();
			break;
		default:
			printf("\nUnknown choice!\n\n");
			continue;
		}
		
		if(done != 1 && result < 0) 
		{
			ECRelease();
			
			printf("***********************IIC test exit.***********************\r\n");
			return 0;
		}
	}
	
	ECRelease();
	
	printf("***********************IIC test exit.***********************\r\n");
	
	
	return 0;
}

