#include <stdio.h>
#include <stdlib.h>
#include "Susi.h"
#include "rel_debug.h"
#include "rel_errlib.h"
#include "rel_errdrv.h"

HSUSI hSusi;

int ECInit()
{
	if (!SusiDllInitialize())
	{
		printf("SusiDllInitialize() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInitialize() OK.\r\n");
	}
	
	if( !SusiDllInstall(1) )
	{
		SusiDllUninitialize();
		printf("SusiDllInstall(1) failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInstall(1) OK.\r\n");
	}
	
	if (!SusiBoardOpen(0,0,0, &hSusi))
	{
		SusiDllInstall(0);
		SusiDllUninitialize();
		printf("SusiBoardOpen() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiBoardOpen() OK.\r\n");
	}
	
	return 0;
}

void ECRelease()
{
	SusiBoardClose(hSusi);
	
	SusiDllInstall(0);
	
	SusiDllUninitialize();
}

void show_menu(void)
{
	printf("\r\n");
	printf("0) Terminate this program\r\n");
	printf("1) Scan exist device\r\n");	
	printf("2) Quick read\r\n");
	printf("3) Quick write\r\n");	
	printf("4) Receive byte\r\n");
	printf("5) Send byte\r\n");
	printf("6) Byte data read\r\n");
	printf("7) Byte data write\r\n");
	printf("8) Word data read\r\n");
	printf("9) Word data write\r\n");
	printf("Enter your choice: \r\n");
}

int scan_dev()
{
	int iResult;
	int i;

	printf("Scan SMBus devices...\r\n");

	for(i = 1; i < 0x7F; i ++)
	{
		iResult = SusiSMBusScanDevice( hSusi, i );
		switch( iResult )
		{
		case -1:
			printf("SMBus is still not be initialize successful!!!\r\n");
			return 0;		
		case 0:
			break;
		case 1:
			printf("%d(0x%X,%d<<1) ", (i << 1), (i << 1), i );
			break;
		default:
			break;
		}
	} /*for(i = 0; i < 0x7F; i ++)*/

	return 0;
}

int quick_read()
{
	int data;
	unsigned char Addr;

	printf("Input 8-bit device address ( 7-bit addr << 1 ):\r\n");
	scanf("%i", &data);
	Addr = (unsigned char) data;

	if( SusiSMBusReadQuick( hSusi, Addr ) )
	{
		printf("Quick Read OK.\r\n");
	}
	else
	{
		printf("Quick Read failed!!!\r\n");
	}

	return 0;
}

int quick_write()
{
	int data;
	unsigned char Addr;
	
	printf("Input 8-bit device address ( 7-bit addr << 1 ):\r\n");
	scanf("%i", &data);
	Addr = (unsigned char) data;
	
	if( SusiSMBusWriteQuick( hSusi, Addr ) )
	{
		printf("Quick Write OK.\r\n");
	}
	else
	{
		printf("Quick Write failed!!!\r\n");
	}
	
	return 0;
}

int receive_byte()
{
	int data;
	unsigned char Addr;
	unsigned char byData;
	
	printf("Input 8-bit device address ( 7-bit addr << 1 ):\r\n");
	scanf("%i", &data);
	Addr = (unsigned char) data;
	
	if( SusiSMBusReceiveByte( hSusi, Addr, &byData ) )
	{
		printf("Receive byte OK. Data: 0x%X\r\n", byData);
	}
	else
	{
		printf("Receive byte failed!!!\r\n");
	}
	
	return 0;
}

int send_byte()
{
	int data;
	unsigned char Addr;
	unsigned char byData;
	
	printf("Input 8-bit device address ( 7-bit addr << 1 ):\r\n");
	scanf("%i", &data);
	Addr = (unsigned char) data;

	printf("Input byte data to be writed:\r\n");
	scanf("%i", &data);
	byData = (unsigned char) data;
	
	if( SusiSMBusSendByte( hSusi, Addr, byData ) )
	{
		printf("Send byte OK.\r\n" );
	}
	else
	{
		printf("Send byte failed!!!\r\n");
	}
	
	return 0;
}

int byte_read()
{
	int data;
	unsigned char Addr;
	unsigned char byOffset;
	unsigned char byData;
	
	printf("Input 8-bit device address ( 7-bit addr << 1 ):\r\n");
	scanf("%i", &data);
	Addr = (unsigned char) data;
	
	printf("Input operation command (or offset):\r\n");
	scanf("%i", &data);
	byOffset = (unsigned char) data;
	
	if( SusiSMBusReadByte( hSusi, Addr, byOffset, &byData ) )
	{
		printf("Byte read OK. Data: 0x%X\r\n", byData);
	}
	else
	{
		printf("Byte read failed!!!\r\n");
	}
	
	return 0;
}

int byte_write()
{
	int data;
	unsigned char Addr;
	unsigned char byOffset;
	unsigned char byData;
	
	printf("Input 8-bit device address ( 7-bit addr << 1 ):\r\n");
	scanf("%i", &data);
	Addr = (unsigned char) data;
	
	printf("Input operation command (or offset):\r\n");
	scanf("%i", &data);
	byOffset = (unsigned char) data;

	printf("Input byte data to be writed:\r\n");
	scanf("%i", &data);
	byData = (unsigned char) data;
	
	if( SusiSMBusWriteByte( hSusi, Addr, byOffset, byData ) )
	{
		printf("Byte write OK.\r\n" );
	}
	else
	{
		printf("Byte write failed!!!\r\n");
	}
	
	return 0;
}

int word_read()
{
	int data;
	unsigned char Addr;
	unsigned char byOffset;
	unsigned short wData;
	
	printf("Input 8-bit device address ( 7-bit addr << 1 ):\r\n");
	scanf("%i", &data);
	Addr = (unsigned char) data;
	
	printf("Input operation command (or offset):\r\n");
	scanf("%i", &data);
	byOffset = (unsigned char) data;
	
	if( SusiSMBusReadWord( hSusi, Addr, byOffset, &wData ) )
	{
		printf("Word read OK. Data: 0x%X\r\n", wData);
	}
	else
	{
		printf("Word read failed!!!\r\n");
	}
	
	return 0;
}

int word_write()
{
	int data;
	unsigned char Addr;
	unsigned char byOffset;
	unsigned short wData;
	
	printf("Input 8-bit device address ( 7-bit addr << 1 ):\r\n");
	scanf("%i", &data);
	Addr = (unsigned char) data;
	
	printf("Input operation command (or offset):\r\n");
	scanf("%i", &data);
	byOffset = (unsigned char) data;
	
	printf("Input word (2 byte) data to be writed:\r\n");
	scanf("%i", &data);
	wData = (unsigned short) data;
	
	if( SusiSMBusWriteWord( hSusi, Addr, byOffset, wData ) )
	{
		printf("Word write OK.\r\n" );
	}
	else
	{
		printf("Word write failed!!!\r\n");
	}
	
	return 0;
}

int main( int argc, char *argv[] )
{
	int result, done, op;
	
	printf("***********************SMBus test enter.***********************\r\n");
	
	if ( 0 != ECInit() )
	{
		printf("EC Init failed.\r\n");
		return -1;
	}
	else
	{
		printf("EC Init OK.\r\n");
	}

	done = 0;
	result = 0;
	
	while (!done)
	{
		show_menu();
		
		scanf("%i", &op);
		
		switch (op)
		{
		case 0:
			done = 1;
			continue;
		case 1:
			result = scan_dev();
			break;
		case 2:
			result = quick_read();
			break;
		case 3:
			result = quick_write();
			break;
		case 4:
			result = receive_byte();
			break;
		case 5:
			result = send_byte();
			break;
		case 6:
			result = byte_read();
			break;
		case 7:
			result = byte_write();
			break;
		case 8:
			result = word_read();
			break;
		case 9:
			result = word_write();
			break;
		default:
			printf("\r\nUnknown choice!\r\n");	
		} /*switch (op)*/

		if(done != 1 && result < 0) 
		{
			ECRelease();
			
			printf("***********************SMBus test exit.***********************\r\n");
			return 0;
		}

	} /*while (!done)*/
	
	ECRelease();

	printf("***********************SMBus test exit.***********************\r\n");

	return 0;
}

