#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "Susi.h"
#include "rel_debug.h"
#include "rel_errlib.h"
#include "rel_errdrv.h"

HSUSI hSusi;

int ECInit()
{
	if (!SusiDllInitialize())
	{
		printf("SusiDllInitialize() failed.\n");
		return -1;
	}
	else
	{
		printf("SusiDllInitialize() OK.\n");
	}
	
	if( !SusiDllInstall(1) )
	{
		SusiDllUninitialize();
		printf("SusiDllInstall(1) failed.\n");
		return -1;
	}
	else
	{
		printf("SusiDllInstall(1) OK.\n");
	}
	
	if (!SusiBoardOpen(0,0,0, &hSusi))
	{
		SusiDllInstall(0);
		SusiDllUninitialize();
		printf("SusiBoardOpen() failed.\n");
		return -1;
	}
	else
	{
		printf("SusiBoardOpen() OK.\n");
	}
	
	return 0;
}

void ECRelease()
{
	SusiBoardClose(hSusi);
	
	SusiDllInstall(0);
	
	SusiDllUninitialize();
}

int base_info()
{
	printf("Base info:\n");	
	printf( "Storage Area count is: %ld.\n", SusiStorageAreaCount(hSusi, 0) );
	printf( "Storage Area type is: 0x%lX.\n", SusiStorageAreaType(hSusi, 0) );
	printf( "Storage Area size is: %ld.\n", SusiStorageAreaSize(hSusi, 0) );
	printf( "Storage Area block size is: %ld.\n", SusiStorageAreaBlockSize(hSusi, 0) );

	return 0;
}

int show_lockstatus()
{
	if( SusiStorageAreaIsLocked(hSusi, 0, 0) )
	{
		printf("Storage Area is locked now, and can not write or erase data.\n");
	}
	else
	{
		printf("Storage Area is unlocked now, and can write or erase data.\n");
	}

	return 0;
}

int lock_area()
{
	char ch;
	char str[100] = {0};
	int len;
	printf("Please input the security key to lock:\n");
	while( (ch=getchar())!='\n' && ch!=EOF )
	{
	}
	fgets(str, 100, stdin);
	len = strlen(str);
	str[len-1] = 0;
	if ( SusiStorageAreaLock(hSusi, 0, 0, (unsigned char*)str, len-1) )
	{
		printf("Lock Ok.\n");
	}
	else
	{
		printf("Lock failed!!!\n");
	}

	return 0;	
}

int unlock_area()
{
	char ch;
	char str[100] = {0};
	int len;
	printf("Please input the security key to unlock:\n");
	while( (ch=getchar())!='\n' && ch!=EOF )
	{
	}
	fgets(str, 100, stdin);
	len = strlen(str);
	str[len-1] = 0;
	if ( SusiStorageAreaUnlock(hSusi, 0, 0, (unsigned char*)str, len-1) )
	{
		printf("Unlock Ok.\n");
	}
	else
	{
		printf("Unlock failed!!!\n");
	}
	
	return 0;	
}

int erase_area()
{
	int data;
	unsigned long offset;
	unsigned long len;
	unsigned long status;

	printf("Offset:\n");
	scanf("%i", &data);
	offset = (unsigned long) data;

	printf("Length:\n");
	scanf("%i", &data);
	len = (unsigned long) data;

	if( SusiStorageAreaErase(hSusi, 0, offset, len) )
	{
		printf("Erase Ok.\n");
	}
	else
	{
		printf("Erase failed!!!\n");
	}

	if( SusiStorageAreaEraseStatus(hSusi, 0, offset, len, &status) )
	{
		if(!status)
		{
			printf("Erase check Ok.\n");
		}
		else
		{
			printf("Erase check failed!!!\n");
		}
	}
	else
	{
		printf("Erase check error.\n");
	}
	
	return 0;
}

int read_area()
{
	int data;
	unsigned long offset;
	unsigned long len;
	unsigned char byData[64];
	unsigned long i;
	
	printf("Offset:\n");
	scanf("%i", &data);
	offset = (unsigned long) data;

	printf("Length:\n");
	scanf("%i", &data);
	len = (unsigned long) data;

	if(SusiStorageAreaRead(hSusi, 0, offset, byData, len ) )
	{
		printf("Read Ok.\n");
		for(i = 0; i < len; i ++ )
		{
			printf("Offset %ld data: 0x%X\n", offset+i, byData[i]);
		}
	}
	else
	{
		printf("Read failed!!!\n");
	}

	return 0;
}

int write_area()
{
	int data;
	unsigned long offset;
	unsigned long len;
	unsigned char byData[64];
	unsigned long i;
	
	printf("Offset:\n");
	scanf("%i", &data);
	offset = (unsigned long) data;
	
	printf("Length:\n");
	scanf("%i", &data);
	len = (unsigned long) data;

	for( i = 0; i < len; i ++ )
	{
		printf("Please input offset %ld data:\n", offset+i);
		scanf("%i", &data);
		byData[i] = (unsigned char) data;
	}
	
	if(SusiStorageAreaWrite(hSusi, 0, offset, byData, len ) )
	{
		printf("Write Ok.\n");		
	}
	else
	{
		printf("Write failed!!!\n");
	}
	
	return 0;
}


void show_menu(void)
{
	printf("\n");
	printf("0) Terminate this program\n");
	printf("1) Show information\n");
	printf("2) Show Lock status\n");	
	printf("3) Lock Storage Area\n");		
	printf("4) Unlock Storage Area\n");
	printf("5) Erase data\n");
	printf("6) Read data\n");
	printf("7) Write data\n");
	printf("Enter your choice: \n");
}


int main( int argc, char *argv[] )
{
	int result, done, op;
	
	printf("***********************EEPROM test enter.***********************\n");
	
	if ( 0 != ECInit() )
	{
		printf("EC Init failed.\n");
		return -1;
	}
	else
	{
		printf("EC Init OK.\n");
	}

	done = 0;
	result = 0;
	
	while (!done)
	{
		show_menu();
		
		scanf("%i", &op);
		
		switch (op)
		{
		case 0:
			done = 1;
			continue;
		case 1:
			result = base_info();
			break;
		case 2:
			result = show_lockstatus();
			break;
		case 3:
			result = lock_area();
			break;
		case 4:
			result = unlock_area();
			break;
		case 5:
			result = erase_area();
			break;
		case 6:
			result = read_area();
			break;
		case 7:
			result = write_area();
			break;
		default:
			printf("\nUnknown choice!\n");	
		} /*switch (op)*/
		
		if(done != 1 && result < 0) 
		{
			ECRelease();
			
			printf("***********************EEPROM test exit.***********************\n");
			return 0;
		}
		
	} /*while (!done)*/
	
	ECRelease();

	printf("***********************EEPROM test exit.***********************\n");

	return 0;
}

