#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "Susi.h"
#include "rel_debug.h"
#include "rel_errlib.h"
#include "rel_errdrv.h"

HSUSI hSusi;

int ECInit()
{
	if (!SusiDllInitialize())
	{
		printf("SusiDllInitialize() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInitialize() OK.\r\n");
	}
	
	if( !SusiDllInstall(1) )
	{
		SusiDllUninitialize();
		printf("SusiDllInstall(1) failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInstall(1) OK.\r\n");
	}
	
	if (!SusiBoardOpen(0,0,0, &hSusi))
	{
		SusiDllInstall(0);
		SusiDllUninitialize();
		printf("SusiBoardOpen() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiBoardOpen() OK.\r\n");
	}
	
	return 0;
}

void ECRelease()
{
	SusiBoardClose(hSusi);
	
	SusiDllInstall(0);
	
	SusiDllUninitialize();
}

int get_count()
{	
	printf("Temperature Count: %ld\r\n", SusiTemperatureCount(hSusi));
	
	return 0;
}

int get_info()
{
	SUSITEMPERATUREINFO Info;
	int data;
	unsigned long unit;

	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	if( SusiTemperatureGetInfo(hSusi, unit, &Info) )
	{
		printf("Info.dwType: 0x%lX\r\n",Info.dwType);
		printf("Info.dwRes: %ld\r\n",Info.dwRes);
	}
	else
	{
		printf("Get info failed!!!\r\n");
	}

	return 0;
}

int get_current()
{
	int data;
	unsigned long unit;
	unsigned long value;
	unsigned long status;

	
	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;
	
	if( SusiTemperatureGetCurrent(hSusi, unit, &value, &status) )
	{
		printf("Value: %ld\r\n",value);
		printf("Status: %ld\r\n",status);
	}
	else
	{
		printf("Get value failed!!!\r\n");
	}
	
	return 0;
}

void show_menu(void)
{
	printf("\r\n");
	printf("0) Terminate this program\r\n");
	printf("1) Get temperature count\r\n");
	printf("2) Get target temperature info\r\n");	
	printf("3) Get target temperature current value\r\n");		
	printf("Enter your choice: \r\n");
}

int main( int argc, char *argv[] )
{
	int result, done, op;
	
	printf("***********************Temperature test enter.***********************\r\n");
	
	if ( 0 != ECInit() )
	{
		printf("EC Init failed.\r\n");
		return -1;
	}
	else
	{
		printf("EC Init OK.\r\n");
	}

	done = 0;
	result = 0;
	
	while (!done)
	{
		show_menu();
		
		scanf("%i", &op);
		
		switch (op)
		{
		case 0:
			done = 1;
			continue;
		case 1:
			result = get_count();
			break;
		case 2:
			result = get_info();
			break;
		case 3:
			result = get_current();
			break;		
		default:
			printf("\r\nUnknown choice!\r\n");	
		} /*switch (op)*/
		
		if(done != 1 && result < 0) 
		{
			ECRelease();
			
			printf("***********************Temperature test exit.***********************\r\n");
			return 0;
		}
		
	} /*while (!done)*/
	
	ECRelease();

	printf("***********************Temperature test exit.***********************\r\n");

	return 0;
}

