#include <stdio.h>
#include <stdlib.h>
#include "Susi.h"
#include "rel_debug.h"
#include "rel_errlib.h"
#include "rel_errdrv.h"

HSUSI hSusi;

int ECInit()
{
	if (!SusiDllInitialize())
	{
		printf("SusiDllInitialize() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInitialize() OK.\r\n");
	}
	
	if( !SusiDllInstall(1) )
	{
		SusiDllUninitialize();
		printf("SusiDllInstall(1) failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInstall(1) OK.\r\n");
	}
	
	if (!SusiBoardOpen(0,0,0, &hSusi))
	{
		SusiDllInstall(0);
		SusiDllUninitialize();
		printf("SusiBoardOpen() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiBoardOpen() OK.\r\n");
	}
	
	return 0;
}

void ECRelease()
{
	SusiBoardClose(hSusi);
	
	SusiDllInstall(0);
	
	SusiDllUninitialize();
}

int get_count()
{	
	printf("VGA Count: %ld\r\n", SusiVgaCount(hSusi));
	
	return 0;
}

int get_info()
{
	SUSIVGAINFO Info;
	int data;
	unsigned long unit;

	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	if( SusiVgaGetInfo(hSusi, unit, &Info) )
	{
		printf("Info.dwType: 0x%lX\r\n",Info.dwType);
	}
	else
	{
		printf("Get info failed!!!\r\n");
	}

	return 0;
}

int get_brightness()
{
	int data;
	unsigned long unit;
	unsigned long value;

	
	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;
	
	if( SusiVgaGetBacklight(hSusi, unit, &value) )
	{
		printf("Brightness: %ld\r\n",value);
	}
	else
	{
		printf("Get brightness failed!!!\r\n");
	}
	
	return 0;
}

int set_brightness()
{
	int data;
	unsigned long unit;
	unsigned long value;
	
	
	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	printf("Please input brightness value:\r\n");
	scanf("%i", &data);
	value = (unsigned long) data;
	
	if( SusiVgaSetBacklight(hSusi, unit, value) )
	{
		printf("Set brightness Ok.\r\n");
	}
	else
	{
		printf("Get brightness failed!!!\r\n");
	}
	
	return 0;
}

void show_menu(void)
{
	printf("\r\n");
	printf("0) Terminate this program\r\n");
	printf("1) Get VGA count\r\n");
	printf("2) Get target VGA info\r\n");	
	printf("3) Get target VGA current brightness\r\n");
	printf("4) Set target VGA current brightness\r\n");
	printf("Enter your choice: \r\n");
}

int main( int argc, char *argv[] )
{
	int result, done, op;
	
	printf("***********************VGA test enter.***********************\r\n");
	
	if ( 0 != ECInit() )
	{
		printf("EC Init failed.\r\n");
		return -1;
	}
	else
	{
		printf("EC Init OK.\r\n");
	}

	done = 0;
	result = 0;
	
	while (!done)
	{
		show_menu();
		
		scanf("%i", &op);
		
		switch (op)
		{
		case 0:
			done = 1;
			continue;
		case 1:
			result = get_count();
			break;
		case 2:
			result = get_info();
			break;
		case 3:
			result = get_brightness();
			break;	
		case 4:
			result = set_brightness();
			break;
		default:
			printf("\r\nUnknown choice!\r\n");	
		} /*switch (op)*/
		
		if(done != 1 && result < 0) 
		{
			ECRelease();
			
			printf("***********************VGA test exit.***********************\r\n");
			return 0;
		}
		
	} /*while (!done)*/
	
	ECRelease();

	printf("***********************VGA test exit.***********************\r\n");

	return 0;
}

