#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "Susi.h"
#include "rel_debug.h"
#include "rel_errlib.h"
#include "rel_errdrv.h"

HSUSI hSusi;

int ECInit()
{
	if (!SusiDllInitialize())
	{
		printf("SusiDllInitialize() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInitialize() OK.\r\n");
	}
	
	if( !SusiDllInstall(1) )
	{
		SusiDllUninitialize();
		printf("SusiDllInstall(1) failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiDllInstall(1) OK.\r\n");
	}
	
	if (!SusiBoardOpen(0,0,0, &hSusi))
	{
		SusiDllInstall(0);
		SusiDllUninitialize();
		printf("SusiBoardOpen() failed.\r\n");
		return -1;
	}
	else
	{
		printf("SusiBoardOpen() OK.\r\n");
	}
	
	return 0;
}

void ECRelease()
{
	SusiBoardClose(hSusi);
	
	SusiDllInstall(0);
	
	SusiDllUninitialize();
}

int get_count()
{	
	printf("Voltage Count: %ld\r\n", SusiVoltageCount(hSusi));
	
	return 0;
}

void volt_name(char* str, unsigned long type)
{
	switch(type)
	{
	case SUSI_VOLTAGE_CPU:
		strcpy(str,"CPU Volt");	
			break;
	case SUSI_VOLTAGE_DC:
		strcpy(str,"DC Volt");	
			break;
	case SUSI_VOLTAGE_DC_STANDBY:
		strcpy(str,"DC STANDBY Volt");
			break;
	case SUSI_VOLTAGE_BAT_CMOS:
		strcpy(str,"BAT CMOS Volt");
			break;
	case SUSI_VOLTAGE_BAT_POWER:
		strcpy(str,"BAT POWER Volt");
			break;
	case SUSI_VOLTAGE_AC:
		strcpy(str,"AC Volt");	
			break;
	case SUSI_VOLTAGE_OTHER:
		strcpy(str,"OTHER Volt");
			break;
	case SUSI_VOLTAGE_5V_S0:
		strcpy(str,"5V S0 Volt");	
			break;
	case SUSI_VOLTAGE_5V_S5:
		strcpy(str,"5V S5 Volt");
			break;
	case SUSI_VOLTAGE_33V_S0:
		strcpy(str,"3.3V S0 Volt");	
			break;
	case SUSI_VOLTAGE_33V_S5:
		strcpy(str,"3.3V S5 Volt");	
			break;
	case SUSI_VOLTAGE_VCOREA:
		strcpy(str,"CORE A Volt");
			break;
	case SUSI_VOLTAGE_VCOREB:
		strcpy(str,"CORE B Volt");
			break;
	case SUSI_VOLTAGE_12V_S0:
		strcpy(str,"12V S0 Volt");
			break;
	default:
		str = "";
		break;
	}
}

int get_info()
{
	SUSIVOLTAGEINFO Info;
	int data;
	unsigned long unit;
	char str[50] = {0};

	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	if( SusiVoltageGetInfo(hSusi, unit, &Info) )
	{
		volt_name(str, Info.dwType);	
		printf("Info.dwType: %s\r\n", str);
		printf("Info.dwRes: %ld\r\n", Info.dwRes);
	}
	else
	{
		printf("Get info failed!!!\r\n");
	}

	return 0;
}

int get_current()
{
	int data;
	unsigned long unit;
	unsigned long value;
	unsigned long status;

	
	printf("Please input unit number:\r\n");
	scanf("%i", &data);
	unit = (unsigned long) data;
	
	if( SusiVoltageGetCurrent(hSusi, unit, &value, &status) )
	{
		printf("Value: %ld mV\r\n",value);
		printf("Status: %ld\r\n",status);
	}
	else
	{
		printf("Get value failed!!!\r\n");
	}
	
	return 0;
}

void show_menu(void)
{
	printf("\r\n");
	printf("0) Terminate this program\r\n");
	printf("1) Get voltage count\r\n");
	printf("2) Get target voltage info\r\n");	
	printf("3) Get target voltage current value\r\n");		
	printf("Enter your choice: \r\n");
}

int main( int argc, char *argv[] )
{
	int result, done, op;
	
	printf("***********************Voltage test enter.***********************\r\n");
	
	if ( 0 != ECInit() )
	{
		printf("EC Init failed.\r\n");
		return -1;
	}
	else
	{
		printf("EC Init OK.\r\n");
	}

	done = 0;
	result = 0;
	
	while (!done)
	{
		show_menu();
		
		scanf("%i", &op);
		
		switch (op)
		{
		case 0:
			done = 1;
			continue;
		case 1:
			result = get_count();
			break;
		case 2:
			result = get_info();
			break;
		case 3:
			result = get_current();
			break;		
		default:
			printf("\r\nUnknown choice!\r\n");	
		} /*switch (op)*/
		
		if(done != 1 && result < 0) 
		{
			ECRelease();
			
			printf("***********************Voltage test exit.***********************\r\n");
			return 0;
		}
		
	} /*while (!done)*/
	
	ECRelease();

	printf("***********************Voltage test exit.***********************\r\n");

	return 0;
}

