#include <stdio.h>
#include <stdlib.h>
#include "Susi.h"
#include "rel_debug.h"
#include "rel_errlib.h"
#include "rel_errdrv.h"

HSUSI hSusi;
unsigned long ulWDCount = 0;

int ECInit()
{
	if (!SusiDllInitialize())
	{
		printf("SusiDllInitialize() failed.\n");
		return -1;
	}
	else
	{
		printf("SusiDllInitialize() OK.\n");
	}
	
	if( !SusiDllInstall(1) )
	{
		SusiDllUninitialize();
		printf("SusiDllInstall(1) failed.\n");
		return -1;
	}
	else
	{
		printf("SusiDllInstall(1) OK.\n");
	}
	
	if (!SusiBoardOpen(0,0,0, &hSusi))
	{
		SusiDllInstall(0);
		SusiDllUninitialize();
		printf("SusiBoardOpen() failed.\n");
		return -1;
	}
	else
	{
		printf("SusiBoardOpen() OK.\n");
	}
	
	return 0;
}

void ECRelease()
{
	SusiBoardClose(hSusi);
	
	SusiDllInstall(0);
	
	SusiDllUninitialize();
}

void CheckAvailableWD()
{
	int i;
	
	for( i = 0; i < ulWDCount; i ++ )
	{
		if( SusiWDogIsAvailable( hSusi, i ) )
		{
			printf( " WD Unit %d exist.\n", i );
		}
		else
		{
			printf( " WD Unit %d is not available.\n", i );
		}
	}	
}

int get_info()
{
	int data;
	unsigned long unit;
	SUSIWDINFO Info = {0};
	
	printf("Which WD Unit:\n");
	scanf("%i", &data);
	unit = (unsigned long) data;
	
	if( SusiWDogGetInfo( hSusi, unit, &Info ) )
	{
		printf("WD Unit %ld base information:\n", unit);
		printf("Info.dwMinTimeout: %ld ms\n", Info.dwMinTimeout);
		printf("Info.dwMaxTimeout: %ld ms\n", Info.dwMaxTimeout);
		printf("Info.dwMinDelay: %ld ms\n", Info.dwMinDelay);
		printf("Info.dwMaxDelay: %ld ms\n", Info.dwMaxDelay);
		printf("Info.dwOpModes (mask): 0x%lX\n", Info.dwOpModes);
		printf("Info.dwEvents (mask): 0x%lX\n", Info.dwEvents);
		printf("Info.dwType: 0x%lX\n", Info.dwType);		
		printf("Info.dwMaxStageCount: %ld\n", Info.dwMaxStageCount);
	}
	else
	{
		printf("Get WD Unit %ld base information failed!!!\n", unit);
		return 0;
	}
	
	return 0;
}

int get_config()
{
	int data;
	unsigned long unit;
	SUSIWDCONFIG Config = {0};
	
	printf("Which WD Unit:\n");
	scanf("%i", &data);
	unit = (unsigned long) data;
	
	if( SusiWDogGetConfigStruct( hSusi, unit, &Config ) )
	{
		printf("WD Unit %ld config information:\n", unit);
		printf("Config.dwTimeout: %ld ms\n", Config.dwTimeout);
		printf("Config.dwDelay: %ld ms\n", Config.dwDelay);	
		printf("Config.dwMode: 0x%lX\n", Config.dwMode);
		printf("Config.dwOpMode: 0x%lX\n", Config.dwOpMode);
		printf("Config.dwStageCount: %ld\n", Config.dwStageCount);
		printf("Config.stStages[0].dwEvent: %lX\n", Config.stStages[0].dwEvent);
		printf("Config.stStages[0].dwTimeout: %ld ms\n", Config.stStages[0].dwTimeout);
		printf("Config.stStages[1].dwEvent: %lX\n", Config.stStages[1].dwEvent);
		printf("Config.stStages[1].dwTimeout: %ld ms\n", Config.stStages[1].dwTimeout);
		printf("Config.stStages[2].dwEvent: %lX\n", Config.stStages[2].dwEvent);
		printf("Config.stStages[2].dwTimeout: %ld ms\n", Config.stStages[2].dwTimeout);
	}
	else
	{
		printf("Get WD Unit %ld config information failed!!!\n", unit);
		return 0;
	}
	
	return 0;
}

void call_back()
{
	printf("CallBack function called.\n");
}

int set_config()
{
	int data;
	unsigned long unit;
	SUSIWDCONFIG Config = {0};
	
	printf("Which WD Unit:\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	printf("Input Config.dwDelay (ms):\n");
	scanf("%i", &data);
	Config.dwDelay = (unsigned long) data;	
	
	printf("Input Config.dwMode (0: Reboot, 1: Shutdown, 2: Staged Event):\n");
	scanf("%i", &data);
	switch( data )
	{
	case 0:
		Config.dwMode = SUSI_WDOG_MODE_REBOOT_PC;
		printf("Input Config.dwTimeout (ms):\n");
		scanf("%i", &data);
		Config.dwTimeout = (unsigned long) data;
		break;
	case 1:
		Config.dwMode = SUSI_WDOG_MODE_SHUTDOWN_OS;
		printf("Input Config.dwTimeout (ms):\n");
		scanf("%i", &data);
		Config.dwTimeout = (unsigned long) data;
		break;
	case 2:
		Config.dwMode = SUSI_WDOG_MODE_STAGED;
		break;
	default:
		printf("Data input wrong, default set \"Reboot\" system mode.\n");
		Config.dwMode = SUSI_WDOG_MODE_REBOOT_PC;
	}

	switch( Config.dwMode )
	{
	case SUSI_WDOG_MODE_REBOOT_PC:
	case SUSI_WDOG_MODE_SHUTDOWN_OS:
		break;

	case SUSI_WDOG_MODE_STAGED:
		printf("Input Config.dwOpMode (0: DISABLED, 1: ONETIME_TRIG):\n");
		scanf("%i", &data);
		switch(data)
		{
		case 0:
			Config.dwOpMode = SUSI_WDOG_OPMODE_DISABLED;
			goto P_SET_CONFIG;
		case 1:	
			Config.dwOpMode = SUSI_WDOG_OPMODE_ONETIME_TRIG;
			break;
		default:
			Config.dwOpMode = SUSI_WDOG_OPMODE_DISABLED;
			printf("Data input wrong, default set \"DISABLED\" operation mode.\n");
			goto P_SET_CONFIG;
		}
		
		printf("Input Config.dwStageCount (1, 2, 3):\n");
		scanf("%i", &data);
		Config.dwStageCount = (unsigned long) data;
		if( (Config.dwStageCount == 0) || (Config.dwStageCount > 3) )
		{
			Config.dwStageCount = 3;
		}

		if( Config.dwStageCount >= 1 )
		{
			printf("Input Config.stStages[0].dwTimeout (ms):\n");
			scanf("%i", &data);
			Config.stStages[0].dwTimeout = (unsigned long) data;

			printf("Input Config.stStages[0].dwEvent (0: INT, 1: SCI, 2: Reboot, 3: Shutdown):\n");
			scanf("%i", &data);
			switch(data)
			{
			case 0:
				Config.stStages[0].dwEvent = SUSI_WDOG_EVENT_INT;
				SusiWDogSetIntCallBack(hSusi, unit, call_back);				
				break;			
			case 1:
				Config.stStages[0].dwEvent = SUSI_WDOG_EVENT_SCI;
				break;
			case 2:
				Config.stStages[0].dwEvent = SUSI_WDOG_EVENT_RST;
				break;
			case 3:
				Config.stStages[0].dwEvent = SUSI_WDOG_EVENT_BTN;
				break;
			default:
				Config.stStages[0].dwEvent = SUSI_WDOG_EVENT_INT;
				SusiWDogSetIntCallBack(hSusi, unit, call_back);
				printf("Data input wrong, default set \"INT\" event.\n");
				break;
			}			
		}

		if( Config.dwStageCount >= 2 )
		{
			printf("Input Config.stStages[1].dwTimeout (ms):\n");
			scanf("%i", &data);
			Config.stStages[1].dwTimeout = (unsigned long) data;
			
			printf("Input Config.stStages[1].dwEvent (0: INT, 1: SCI, 2: Reboot, 3: Shutdown):\n");
			scanf("%i", &data);
			switch(data)
			{
			case 0:
				Config.stStages[1].dwEvent = SUSI_WDOG_EVENT_INT;
				SusiWDogSetIntCallBack(hSusi, unit, call_back);
				break;			
			case 1:
				Config.stStages[1].dwEvent = SUSI_WDOG_EVENT_SCI;
				break;
			case 2:
				Config.stStages[1].dwEvent = SUSI_WDOG_EVENT_RST;
				break;
			case 3:
				Config.stStages[1].dwEvent = SUSI_WDOG_EVENT_BTN;
				break;
			default:
				Config.stStages[1].dwEvent = SUSI_WDOG_EVENT_INT;
				SusiWDogSetIntCallBack(hSusi, unit, call_back);
				printf("Data input wrong, default set \"INT\" event.\n");
				break;
			}			
		}

		if( Config.dwStageCount == 3 )
		{
			printf("Input Config.stStages[2].dwTimeout (ms):\n");
			scanf("%i", &data);
			Config.stStages[2].dwTimeout = (unsigned long) data;
			
			printf("Input Config.stStages[2].dwEvent (0: INT, 1: SCI, 2: Reboot, 3: Shutdown):\n");
			scanf("%i", &data);
			switch(data)
			{
			case 0:
				Config.stStages[2].dwEvent = SUSI_WDOG_EVENT_INT;
				SusiWDogSetIntCallBack(hSusi, unit, call_back);
				break;			
			case 1:
				Config.stStages[2].dwEvent = SUSI_WDOG_EVENT_SCI;
				break;
			case 2:
				Config.stStages[2].dwEvent = SUSI_WDOG_EVENT_RST;
				break;
			case 3:
				Config.stStages[2].dwEvent = SUSI_WDOG_EVENT_BTN;
				break;
			default:
				Config.stStages[2].dwEvent = SUSI_WDOG_EVENT_INT;
				SusiWDogSetIntCallBack(hSusi, unit, call_back);
				printf("Data input wrong, default set \"INT\" event.\n");
				break;
			}			
		}
		break;
	} /*switch( Config.dwMode )*/
	
P_SET_CONFIG:
	
	if( SusiWDogSetConfigStruct( hSusi, unit, &Config ) )
	{
		printf("Set WD Unit %ld OK.\n", unit);
		
	}
	else
	{
		printf("Set WD Unit %ld failed!!!\n", unit);
	}
	
	return 0;
}

int quick_set()
{
	int data;
	unsigned long unit;
	unsigned long timeout; 
	unsigned long delay; 
	unsigned long mode;
	
	printf("Which WD Unit:\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	printf("Input Delay (ms):\n");
	scanf("%i", &data);
	delay = (unsigned long) data;
	
	printf("Input Timeout (ms):\n");
	scanf("%i", &data);
	timeout = (unsigned long) data;

	printf("Input Mode (0: Reboot, 1: Shutdown):\n");
	scanf("%i", &data);
	switch(data)
	{
	case 0:
		mode = SUSI_WDOG_MODE_REBOOT_PC;
		break;
	case 1:
		mode = SUSI_WDOG_MODE_SHUTDOWN_OS;
		break;
	default:
		mode = SUSI_WDOG_MODE_REBOOT_PC;
		printf("Data input wrong, default set \"Reboot\" system mode.\n");
		break;
	}	
	
	if( SusiWDogSetConfig( hSusi, unit, timeout, delay, mode ) )
	{
		printf("Quick set WD Unit %ld OK.\n", unit);
		
	}
	else
	{
		printf("Quick set WD Unit %ld failed!!!\n", unit);
	}
	
	return 0;
}

int wd_trigger()
{
	int data;
	unsigned long unit;

	printf("Which WD Unit:\n");
	scanf("%i", &data);
	unit = (unsigned long) data;

	if( SusiWDogTrigger(hSusi, unit) )
	{
		printf("Trigger WD Unit %ld OK.\n", unit);
	}
	else
	{
		printf("Trigger WD Unit %ld failed!!!\n", unit);
	}

	return 0;
}

int wd_disable()
{
	int data;
	unsigned long unit;
	
	printf("Which WD Unit:\n");
	scanf("%i", &data);
	unit = (unsigned long) data;
	
	if( SusiWDogDisable(hSusi, unit) )
	{
		printf("Disable WD Unit %ld OK.\n", unit);
	}
	else
	{
		printf("Disable WD Unit %ld failed!!!\n", unit);
	}

	return 0;
}


void show_menu(void)
{
	printf("\n");
	printf("0) Terminate this program\n");
	printf("1) Show WD information\n");	
	printf("2) Get WD config\n");		
	printf("3) Set WD config\n");
	printf("4) Quick set WD (Not for Staged Mode)\n");
	printf("5) Trigger WD\n");
	printf("6) Disable WD\n");
	printf("Enter your choice: \n");
}

int main( int argc, char *argv[] )
{
	int result, done, op;

	printf("***********************WD test enter.***********************\n");
	
	if ( 0 != ECInit() )
	{
		printf("EC Init failed.\n");
		return -1;
	}
	else
	{
		printf("EC Init OK.\n");
	}

	ulWDCount = SusiWDogCount( hSusi );
	if(!ulWDCount)
	{
		printf("Get WD device count failed!!!\n");
		
		ECRelease();

		printf("***********************WD test exit.***********************\n");
		return -1;
	}

	printf("WD Unit Amount: %ld\n", ulWDCount);

	CheckAvailableWD();

	done = 0;
	result = 0;
	
	while (!done)
	{
		show_menu();
		
		scanf("%i", &op);
		
		switch (op)
		{
		case 0:
			done = 1;
			continue;
		case 1:
			result = get_info();
			break;
		case 2:
			result = get_config();
			break;
		case 3:
			result = set_config();
			break;
		case 4:
			result = quick_set();
			break;
		case 5:
			result = wd_trigger();
			break;
		case 6:
			result = wd_disable();
			break;
		default:
			printf("\nUnknown choice!\n");	
		} /*switch (op)*/
		
		if(done != 1 && result < 0) 
		{
			ECRelease();
			
			printf("***********************WD test exit.***********************\n");
			return 0;
		}
		
	} /*while (!done)*/
	
	ECRelease();

	printf("***********************WD test exit.***********************\n");

	return 0;
}

